<?php

namespace Litecms\Rentals\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Rentals\Models\Rentals;

class RentalsPolicy
{

    /**
     * Determine if the given user can view the rentals.
     *
     * @param UserPolicy $user
     * @param Rentals $rentals
     *
     * @return bool
     */
    public function view(UserPolicy $user, Rentals $rentals)
    {
        if ($user->canDo('rentals.rentals.view') && $user->isAdmin()) {
            return true;
        }

        return $rentals->user_id == user_id() && $rentals->user_type == user_type();
    }

    /**
     * Determine if the given user can create a rentals.
     *
     * @param UserPolicy $user
     * @param Rentals $rentals
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('rentals.rentals.create');
    }

    /**
     * Determine if the given user can update the given rentals.
     *
     * @param UserPolicy $user
     * @param Rentals $rentals
     *
     * @return bool
     */
    public function update(UserPolicy $user, Rentals $rentals)
    {
        if ($user->canDo('rentals.rentals.edit') && $user->isAdmin()) {
            return true;
        }

        return $rentals->user_id == user_id() && $rentals->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given rentals.
     *
     * @param UserPolicy $user
     * @param Rentals $rentals
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Rentals $rentals)
    {
        return $rentals->user_id == user_id() && $rentals->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given rentals.
     *
     * @param UserPolicy $user
     * @param Rentals $rentals
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Rentals $rentals)
    {
        if ($user->canDo('rentals.rentals.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given rentals.
     *
     * @param UserPolicy $user
     * @param Rentals $rentals
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Rentals $rentals)
    {
        if ($user->canDo('rentals.rentals.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
